@@ -21,7 +21,6 @@
  */
 
 #include <giomm/appinfo.h>
-#include <giomm/application.h>
 #include <giomm/asyncresult.h>
 #include <giomm/bufferedinputstream.h>
 #include <giomm/bufferedoutputstream.h>
@@ -71,6 +70,8 @@
 #include <giomm/networkaddress.h>
 #include <giomm/networkservice.h>
 #include <giomm/outputstream.h>
+#include <giomm/proxy.h>
+#include <giomm/proxyresolver.h>
 #include <giomm/resolver.h>
 #include <giomm/seekable.h>
 #include <giomm/settings.h>
