@@ -32,6 +32,9 @@
 #include "unicode.h"
 #include "uriutils.h"
 #include "valuearray.h"
+#include "variant.h"
+#include "variantiter.h"
+#include "varianttype.h"
 
 extern "C"
 {
